/*
 * An opener for a file provided by an Ext2-compatible filesystem.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <ext2fs/ext2fs.h>

#include <fsserver/opener_resource.h>
#include <systypes/user.h>



/* Support for providing access to files. */

class Ext2FileOpener : public OpenerResource
{
protected:
    ext2_filsys _fs;
    sys_uid_t _uid;
    sys_gid_t _gid;
    sys_mode_t _umask;

public:
    explicit Ext2FileOpener(FilePaging *paging, ext2_filsys fs, sys_uid_t uid,
                            sys_gid_t gid, sys_mode_t umask)
    : OpenerResource(paging), _fs(fs), _uid(uid), _gid(gid), _umask(umask)
    {
    }

    /* Configurable methods. */

    virtual fileid_t get_fileid(const char *path, flags_t flags);

    virtual long make_accessor(const char *path, flags_t flags, fileid_t fileid, Accessor **accessor);
};

// vim: tabstop=4 expandtab shiftwidth=4
